# IndexFileFormat

Format of the Index File

## Enum

* `JSON` (value: `'JSON'`)

* `CSV` (value: `'CSV'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


